Administrator's Guide
=====================

This guide is intended for administrators of Zuul systems.  It covers
installation, operation, and the portion of Zuul configuration that
occurs outside of the projects upon which Zuul operates.  Advanced
users may be interested in some of the concepts described here, as
well as understanding what features the underlying configuration
provides to in-project configuration.

.. toctree::
   :maxdepth: 2

   quick-start
   installation
   zuul-from-scratch
   components
   connections
   tenants
   monitoring
   client
   troubleshooting
